#! /usr/bin/env python
"""
usage: %s [-arv] [dirs/files] ...
       byte-compiles python files/dirs
       -a compile all files of current python installation
       -o optimized compile, too
       -r recursive behaviour
       -v verbose level (cumulative)
       dirs/files: to compile
"""
# (c)reated by Hans-Peter Jansen, LISA GmbH, Berlin
#
# Licence:      GPL   http://www.gnu.org/licenses/gpl.html
#
# 2002-11-27    hp    initial version
#
# TODO:
# - testing
#
# vim:set et ts=4 sw=4:

import sys, os
import getopt
import glob
import py_compile

argv0 = os.path.basename(sys.argv[0])
optimize = 0
verbose = 0

def out(lvl, arg):
    if lvl > verbose:
        return
    err(arg, sys.stdout)

def err(arg, ch = sys.stderr):
    if arg:
        ch.write(arg)
        if arg[-1] != "\n":
            ch.write("\n")
    else:
        ch.write("\n")
    ch.flush()

def exit(ret=0, arg=None):
    if arg:
        out(0, "%s: %s" % (argv0, arg))
    sys.exit(ret)

def usage(ret=0, arg=None):
    if arg:
        out(0, "%s: %s" % (argv0, arg))
    out(0, __doc__ % (argv0))
    sys.exit(ret)

def pycompile(path, recursive = 0, depth = 0):
    if os.path.isdir(path):
        for p in glob.glob(os.path.join(path, "*")):
            if depth == 0 or recursive:
                pycompile(p, recursive, depth + 1)
    elif os.path.isfile(path):
        f, e = os.path.splitext(path)
        if e == '.py':
            out(1, "compiling %s" % (path))
            py_compile.compile(path)
            if optimize:
                out(1, "compiling %s (opt)" % (path))
                os.system("python -O %s %s" % (sys.argv[0], path))
    else:
        out(1, "%s ignored" % (path))

if __name__ == '__main__':
    #global verbose, optimize
    try:
        optlist, args = getopt.getopt(sys.argv[1:], "aorv")
    except getopt.error, msg:
        usage(1, msg)

    all = 0
    optimize = 0
    recursive = 0
    for opt, par in optlist:
        if opt == '-a':
            all = 1
        elif opt == '-o':
            optimize = 1
        elif opt == '-r':
            recursive = 1
        elif opt == '-v':
            verbose += 1

    if all:
        pyFullVers = sys.version.split()[0]
        vl = pyFullVers.split(".")
        pyVers = vl[0] + "." + vl[1]
        pycompile(os.path.join(sys.prefix, "lib/python" + pyVers), 1)
    else:
        for p in args:
            pycompile(p, recursive)

